@@ -17,9 +17,10 @@ from plone.z3cform import z2
 from plone.z3cform.fieldsets import extensible
 from plone.z3cform.interfaces import IWrappedForm
 from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone.utils import safe_unicode
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.statusmessages.interfaces import IStatusMessage
-from urllib import quote as url_quote
+from six.moves.urllib.parse import quote
 from z3c.form import button
 from z3c.form import field
 from z3c.form import form
@@ -36,26 +37,26 @@ from zope.interface import alsoProvides
 COMMENT_DESCRIPTION_PLAIN_TEXT = _(
     u'comment_description_plain_text',
     default=u'You can add a comment by filling out the form below. '
-            u'Plain text formatting.'
+            u'Plain text formatting.',
 )
 
 COMMENT_DESCRIPTION_MARKDOWN = _(
     u'comment_description_markdown',
     default=u'You can add a comment by filling out the form below. '
             u'Plain text formatting. You can use the Markdown syntax for '
-            u'links and images.'
+            u'links and images.',
 )
 
 COMMENT_DESCRIPTION_INTELLIGENT_TEXT = _(
     u'comment_description_intelligent_text',
     default=u'You can add a comment by filling out the form below. '
             u'Plain text formatting. Web and email addresses are '
-            u'transformed into clickable links.'
+            u'transformed into clickable links.',
 )
 
 COMMENT_DESCRIPTION_MODERATION_ENABLED = _(
     u'comment_description_moderation_enabled',
-    default=u'Comments are moderated.'
+    default=u'Comments are moderated.',
 )
 
 
@@ -150,13 +151,9 @@ class CommentForm(extensible.ExtensibleForm, form.Form):
 
         # Make sure author_name/ author_email is properly encoded
         if 'author_name' in data:
-            author_name = data['author_name']
-            if isinstance(author_name, str):
-                author_name = unicode(author_name, 'utf-8')
+            author_name = safe_unicode(data['author_name'])
         if 'author_email' in data:
-            author_email = data['author_email']
-            if isinstance(author_email, str):
-                author_email = unicode(author_email, 'utf-8')
+            author_email = safe_unicode(data['author_email'])
 
         # Set comment author properties for anonymous users or members
         portal_membership = getToolByName(context, 'portal_membership')
@@ -165,21 +162,18 @@ class CommentForm(extensible.ExtensibleForm, form.Form):
                 'Reply to item', context):
             # Member
             member = portal_membership.getAuthenticatedMember()
-            # memberdata is stored as utf-8 encoded strings
-            email = member.getProperty('email')
+            email = safe_unicode(member.getProperty('email'))
             fullname = member.getProperty('fullname')
             if not fullname or fullname == '':
                 fullname = member.getUserName()
-            elif isinstance(fullname, str):
-                fullname = unicode(fullname, 'utf-8')
+            fullname = safe_unicode(fullname)
             author_name = fullname
-            if email and isinstance(email, str):
-                email = unicode(email, 'utf-8')
-            # XXX: according to IComment interface author_email must not be
+            email = safe_unicode(email)
+            # XXX: according to IComment interface author_email must not be  # noqa T000
             # set for logged in users, cite:
             # 'for anonymous comments only, set to None for logged in comments'
             author_email = email
-            # /XXX
+            # /XXX  # noqa T000
 
         return author_name, author_email
 
@@ -226,7 +220,7 @@ class CommentForm(extensible.ExtensibleForm, form.Form):
             raise Unauthorized(
                 u'Anonymous user tries to post a comment, but anonymous '
                 u'commenting is disabled. Or user does not have the '
-                u"'reply to item' permission."
+                u"'reply to item' permission.",
             )
 
         return comment
@@ -238,10 +232,10 @@ class CommentForm(extensible.ExtensibleForm, form.Form):
 
         # Check if conversation is enabled on this content object
         if not self.__parent__.restrictedTraverse(
-            '@@conversation_view'
+            '@@conversation_view',
         ).enabled():
             raise Unauthorized(
-                'Discussion is not enabled for this content object.'
+                'Discussion is not enabled for this content object.',
             )
 
         # Validation form
@@ -291,7 +285,7 @@ class CommentForm(extensible.ExtensibleForm, form.Form):
         comment_review_state = workflowTool.getInfoFor(
             comment,
             'review_state',
-            None
+            None,
         )
         if comment_review_state == 'pending' and not can_review:
             # Show info message when comment moderation is enabled
@@ -427,7 +421,7 @@ class CommentsViewlet(ViewletBase):
         """
         if self.get_replies(workflow_actions) is not None:
             try:
-                self.get_replies(workflow_actions).next()
+                next(self.get_replies(workflow_actions))
                 return True
             except StopIteration:  # pragma: no cover
                 pass
@@ -534,7 +528,7 @@ class CommentsViewlet(ViewletBase):
     def login_action(self):
         return '{0}/login_form?came_from={1}'.format(
             self.navigation_root_url,
-            url_quote(self.request.get('URL', '')),
+            quote(self.request.get('URL', '')),
         )
 
     def format_time(self, time):
